@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 BASEIMAGE
 Provides a class to perform basic image loading an manipulation with pygame.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -34,17 +37,26 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 import os.path as path
 import math
 
+try:
+    # noinspection PyCompatibility
+    from pathlib import Path as _Path
+except ImportError:
+    _Path = None
+
 import pygame
 from pygame_menu.utils import assert_vector2
 
-# Example images
-__fontdir = path.join(path.dirname(path.abspath(__file__)), 'resources', 'images', '{0}')
+# Example image paths
+__images_path__ = path.join(path.dirname(path.abspath(__file__)), 'resources', 'images', '{0}')
 
-IMAGE_EXAMPLE_CARBON_FIBER = __fontdir.format('carbon_fiber.png')
-IMAGE_EXAMPLE_GRAY_LINES = __fontdir.format('gray_lines.png')
-IMAGE_EXAMPLE_METAL = __fontdir.format('metal.png')
-IMAGE_EXAMPLE_PYGAME_MENU = __fontdir.format('pygame_menu.png')
-IMAGE_EXAMPLE_WALLPAPER = __fontdir.format('wallpaper.jpg')
+IMAGE_EXAMPLE_CARBON_FIBER = __images_path__.format('carbon_fiber.png')
+IMAGE_EXAMPLE_GRAY_LINES = __images_path__.format('gray_lines.png')
+IMAGE_EXAMPLE_METAL = __images_path__.format('metal.png')
+IMAGE_EXAMPLE_PYGAME_MENU = __images_path__.format('pygame_menu.png')
+IMAGE_EXAMPLE_WALLPAPER = __images_path__.format('wallpaper.jpg')
+
+IMAGE_EXAMPLES = (IMAGE_EXAMPLE_CARBON_FIBER, IMAGE_EXAMPLE_GRAY_LINES, IMAGE_EXAMPLE_METAL,
+                  IMAGE_EXAMPLE_PYGAME_MENU, IMAGE_EXAMPLE_WALLPAPER)
 
 # Drawing modes
 IMAGE_MODE_CENTER = 100
@@ -64,8 +76,8 @@ class BaseImage(object):
     Object that loads an image, stores as a surface, transform it and
     let write the image to an surface.
 
-    :param image_path: Path of the image to be loaded
-    :type image_path: str
+    :param image_path: Path of the image to be loaded. It can be a string or :py:class:`pathlib.Path` on ``Python 3+``
+    :type image_path: str, :py:class:`pathlib.Path`
     :param drawing_mode: Drawing mode of the image
     :type drawing_mode: int
     :param drawing_offset: Offset of the image in drawing method
@@ -80,10 +92,13 @@ class BaseImage(object):
                  drawing_offset=(0, 0),
                  load_from_file=True
                  ):
-        assert isinstance(image_path, str)
-        assert isinstance(drawing_mode, int)
+        if _Path is None:
+            assert isinstance(image_path, str)
+        else:
+            assert isinstance(image_path, (str, _Path))
+            if isinstance(image_path, _Path):
+                image_path = str(image_path)
         assert isinstance(load_from_file, bool)
-        assert_vector2(drawing_offset)
 
         _, file_extension = path.splitext(image_path)
         file_extension = file_extension.lower()
@@ -98,29 +113,68 @@ class BaseImage(object):
         self._extension = file_extension
 
         # Drawing mode
-        self._drawing_mode = drawing_mode
-        self._drawing_offset = (drawing_offset[0], drawing_offset[1])
+        self._drawing_mode = 0
+        self._drawing_offset = (0, 0)
+
+        self.set_drawing_mode(drawing_mode)
+        self.set_drawing_offset(drawing_offset)
 
         # Load the image and store as a surface
         if load_from_file:
             self._surface = pygame.image.load(image_path)  # type: pygame.Surface
             self._original_surface = self._surface.copy()
 
-    def __str__(self):
+    def get_path(self):
         """
-        :return: String definition of the object
+        Return the image path.
+
+        :return: Image path
         :rtype: str
         """
-        msg = 'BaseImage Object {3}\n\tPath: {0}\n\tDrawing mode: {1}\n\tDrawing offset: {2}'
-        return msg.format(self._filepath, self._drawing_mode, self._drawing_offset, hex(id(self)))
+        return self._filepath
 
-    def __repr__(self):
+    def get_drawing_mode(self):
         """
-        Prints the object.
+        Return the image drawing mode.
 
+        :return: Image drawing mode
+        :rtype: int
+        """
+        return self._drawing_mode
+
+    def set_drawing_mode(self, drawing_mode):
+        """
+        Set the image drawing mode.
+
+        :param drawing_mode: Drawing mode
+        :type drawing_mode: int
         :return: None
         """
-        print(self.__str__())
+        assert isinstance(drawing_mode, int)
+        assert drawing_mode in [IMAGE_MODE_CENTER, IMAGE_MODE_FILL, IMAGE_MODE_REPEAT_X,
+                                IMAGE_MODE_REPEAT_Y, IMAGE_MODE_REPEAT_XY, IMAGE_MODE_SIMPLE], \
+            'unknown image drawing mode'
+        self._drawing_mode = drawing_mode
+
+    def get_drawing_offset(self):
+        """
+        Return the image drawing offset.
+
+        :return: Image drawing offset
+        :rtype: tuple
+        """
+        return self._drawing_offset
+
+    def set_drawing_offset(self, drawing_offset):
+        """
+        Set the image drawing offset.
+
+        :param drawing_offset: Drawing offset tuple *(x, y)*
+        :type drawing_offset: tuple, list
+        :return: None
+        """
+        assert_vector2(drawing_offset)
+        self._drawing_offset = (drawing_offset[0], drawing_offset[1])
 
     def copy(self):
         """
@@ -208,7 +262,8 @@ class BaseImage(object):
         """
         Apply a function to each pixel of the image. The function will receive the red, green, blue and alpha
         colors and must return the same values. The color pixel will be overriden by the function output.
-        See ``BaseImage.to_bw()`` method as an example.
+
+        .. note:: See ``BaseImage.to_bw()`` method as an example.
 
         :param image_function: Color function, takes colors as ``image_function=myfunc(r, g, b, a)``. Returns the same tuple *(r,g,b,a)*
         :type image_function: callable
@@ -224,6 +279,7 @@ class BaseImage(object):
                 g = int(max(0, min(g, 255)))
                 b = int(max(0, min(b, 255)))
                 a = int(max(0, min(a, 255)))
+                # noinspection PyArgumentList
                 self._surface.set_at((x, y), pygame.Color(r, g, b, a))
         return self
 
@@ -236,6 +292,9 @@ class BaseImage(object):
         """
 
         def bw(r, g, b, a):
+            """
+            To black-white function.
+            """
             c = (r + g + b) / 3
             return c, c, c, a
 
@@ -268,6 +327,7 @@ class BaseImage(object):
                     g = 0
                 if 'b' not in channels:
                     b = 0
+                # noinspection PyArgumentList
                 self._surface.set_at((x, y), pygame.Color(r, g, b, a))
         return self
 
@@ -320,7 +380,8 @@ class BaseImage(object):
         scale of bitmap graphics.
 
         This really only has an effect on simple images with solid colors.
-        On photographic and antialiased images it will look like a regular unfiltered scale.
+        On photographic and antialiased images it will look like a regular
+        unfiltered scale.
 
         :return: Self reference
         :rtype: BaseImage
@@ -347,9 +408,8 @@ class BaseImage(object):
         assert width > 0 and height > 0, 'width and height must be greater than zero'
         w, h = self.get_size()
         if w == width and h == height:
-            return
-        self.scale(width=float(width) / w, height=float(height) / h, smooth=smooth)
-        return self
+            return self
+        return self.scale(width=float(width) / w, height=float(height) / h, smooth=smooth)
 
     def get_rect(self):
         """
@@ -381,15 +441,6 @@ class BaseImage(object):
         self._surface = pygame.transform.rotate(self._surface, angle)
         return self
 
-    def get_drawing_mode(self):
-        """
-        Return the image drawing mode.
-
-        :return: Image drawing mode
-        :rtype: int
-        """
-        return self._drawing_mode
-
     def draw(self, surface, area=None, position=(0, 0)):
         """
         Draw the image in a given surface.
@@ -398,7 +449,7 @@ class BaseImage(object):
         :type surface: :py:class:`pygame.Surface`
         :param area: Area to draw, if None, Image will be drawn on entire surface
         :type area: :py:class:`pygame.Rect`, None
-        :param position: Position to draw
+        :param position: Position to draw in *(x, y)*
         :type position: tuple
         :return: None
         """
@@ -491,6 +542,3 @@ class BaseImage(object):
                 ),
                 area
             )
-
-        else:
-            raise ValueError('invalid image mode')
