@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 EVENTS
 Menu events definition and locals.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -51,6 +54,18 @@ class MenuAction(object):
         return False
 
 
+def is_event(event):
+    """
+    Check if event is pygame_menu event type.
+
+    :param event: Event
+    :type event: any
+    :return: True if it's event
+    :rtype: bool
+    """
+    return isinstance(event, MenuAction) or str(type(event)) == "<class 'pygame_menu.events.MenuAction'>"
+
+
 # Events
 BACK = MenuAction(0)  # Menu back
 CLOSE = MenuAction(1)  # Close menu
@@ -61,3 +76,9 @@ RESET = MenuAction(5)  # Menu reset
 
 # Pygame events
 PYGAME_QUIT = __locals.QUIT
+
+PYGAME_WINDOWCLOSE = -1
+if hasattr(__locals, 'WINDOWCLOSE'):
+    PYGAME_WINDOWCLOSE = __locals.WINDOWCLOSE
+elif hasattr(__locals, 'WINDOWEVENT_CLOSE'):
+    PYGAME_WINDOWCLOSE = __locals.WINDOWEVENT_CLOSE
