@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - GAME SELECTOR
 Game with 3 difficulty options.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -30,17 +33,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-# Import libraries
-import sys
-
-sys.path.insert(0, '../../')
-
 import os
+from random import randrange
+
 import pygame
 import pygame_menu
 
-from random import randrange
-
 # -----------------------------------------------------------------------------
 # Constants and global variables
 # -----------------------------------------------------------------------------
@@ -49,11 +47,14 @@ ABOUT = ['pygame-menu {0}'.format(pygame_menu.__version__),
          '',  # new line
          'Email: {0}'.format(pygame_menu.__email__)]
 DIFFICULTY = ['EASY']
-FPS = 60.0
+FPS = 60
 WINDOW_SIZE = (640, 480)
 
+# noinspection PyTypeChecker
 clock = None  # type: pygame.time.Clock
+# noinspection PyTypeChecker
 main_menu = None  # type: pygame_menu.Menu
+# noinspection PyTypeChecker
 surface = None  # type: pygame.Surface
 
 
@@ -106,11 +107,11 @@ def play_function(difficulty, font, test=False):
     global clock
 
     if difficulty == 'EASY':
-        f = font.render('Playing as a baby (easy)', 1, (255, 255, 255))
+        f = font.render('Playing as a baby (easy)', True, (255, 255, 255))
     elif difficulty == 'MEDIUM':
-        f = font.render('Playing as a kid (medium)', 1, (255, 255, 255))
+        f = font.render('Playing as a kid (medium)', True, (255, 255, 255))
     elif difficulty == 'HARD':
-        f = font.render('Playing as a champion (hard)', 1, (255, 255, 255))
+        f = font.render('Playing as a champion (hard)', True, (255, 255, 255))
     else:
         raise Exception('Unknown difficulty {0}'.format(difficulty))
 
