@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 WIDGET
 Base class for widgets.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -59,7 +62,7 @@ class Widget(object):
     :param args: Optional arguments for callbacks
     :type args: any
     :param kwargs: Optional keyword arguments
-    :type kwargs: dict
+    :type kwargs: dict, any
     """
 
     def __init__(self,
@@ -70,7 +73,7 @@ class Widget(object):
                  args=None,
                  kwargs=None
                  ):
-        assert isinstance(widget_id, str)
+        assert isinstance(widget_id, str), 'widget id must be a string'
         if onchange:
             assert is_callable(onchange), 'onchange must be callable or None'
         if onreturn:
@@ -102,7 +105,7 @@ class Widget(object):
 
         # Widget rect. This object does not contain padding. For getting the widget+padding
         # use .get_rect() Widget method instead
-        self._rect = pygame.Rect(0, 0, 0, 0)  # type: (pygame.Rect,None)
+        self._rect = pygame.Rect(0, 0, 0, 0)  # type: pygame.Rect
 
         # Callbacks
         self._draw_callbacks = {}  # type: dict
@@ -158,6 +161,7 @@ class Widget(object):
         self.mouse_enabled = True
         self.selected = False
         self.selection_effect_enabled = True  # Some widgets cannot have selection effect
+        self.selection_expand_background = False  # If True, the widget background will inflate to match selection margin if selected
         self.sound = Sound()  # type: Sound
         self.touchscreen_enabled = True
         self.visible = True  # Use .show() or .hide() to modify this status
@@ -235,8 +239,8 @@ class Widget(object):
 
         :param args: Variables to check the hash
         :type args: any
-        :return: Hash data
-        :rtype: int
+        :return: ``True`` if render has changed the widget
+        :rtype: bool
         """
         _hash = self._hash_variables(*args)
         if _hash != self._last_render_hash:
@@ -272,7 +276,7 @@ class Widget(object):
 
         :param color: Widget background color
         :type color: tuple, list, :py:class:`pygame_menu.baseimage.BaseImage`, None
-        :param inflate: Inflate background in *(x,y)*. If None, the widget value is not updated
+        :param inflate: Inflate background in *(x,y)*. If ``None``, the widget value is not updated
         :type inflate: tuple, list, None
         :return: None
         """
@@ -288,9 +292,23 @@ class Widget(object):
         assert inflate[0] >= 0 and inflate[1] >= 0, \
             'widget background inflate must be equal or greater than zero in both axis'
         self._background_color = color
-        self._background_inflate = inflate
+        self._background_inflate = tuple(inflate)
         self._last_render_hash = 0  # Force widget render
 
+    def expand_background_inflate_to_selection_effect(self):
+        """
+        Expand background inflate to match the selection effect
+        (the widget don't require to be selected).
+
+        This is a permanent change; for dynamic purpuoses, depending if the widget
+        is selected or not, setting ``widget.selection_expand_background`` to ``True`` may help.
+
+        .. note:: This method may have unexpected results with certain selection effects.
+
+        :return: None
+        """
+        self._background_inflate = self._selection_effect.get_xy_margin()
+
     def _fill_background_color(self, surface):
         """
         Fill a surface with the widget background color.
@@ -301,9 +319,11 @@ class Widget(object):
         """
         if self._background_color is None:
             return
-        rect = self.get_rect(
-            inflate=(self._background_inflate[0] / 2, self._background_inflate[1] / 2)
-        )
+        if not (self.selection_expand_background and self.selected):
+            inflate = self._background_inflate
+        else:
+            inflate = self._selection_effect.get_xy_margin()
+        rect = self.get_rect(inflate=inflate)
         if isinstance(self._background_color, _baseimage.BaseImage):
             self._background_color.draw(
                 surface=surface,
@@ -421,25 +441,25 @@ class Widget(object):
         :return: None
         """
         if width is not None:
-            assert isinstance(width, (int, float))
+            assert isinstance(width, (int, float)), 'width must be numeric'
         self._max_width = width
 
     def get_margin(self):
         """
         Return the widget margin.
 
-        :return: Widget margin (left, top)
+        :return: Widget margin *(left,bottom)*
         :rtype: tuple
         """
         return self._margin
 
     def set_margin(self, x, y):
         """
-        Set Widget margin (left, top).
+        Set Widget margin (left, bottom).
 
         :param x: Margin on x axis (left)
         :type x: int, float
-        :param y: Margin on y axis (top)
+        :param y: Margin on y axis (bottom)
         :type y: int, float
         :return: None
         """
@@ -491,7 +511,7 @@ class Widget(object):
                 self._padding = (padding[0], padding[1], padding[2], padding[3])
         self._last_render_hash = 0  # Force widget render
 
-    def get_rect(self, inflate=None):
+    def get_rect(self, apply_padding=True, inflate=None):
         """
         Return the Rect object, this forces the widget rendering.
 
@@ -500,6 +520,8 @@ class Widget(object):
             This is the only method that returns the rect with the padding applied.
             If widget._rect is used, the padding has not been applied.
 
+        :param apply_padding: Apply widget padding
+        :type apply_padding: bool
         :param inflate: Inflate rect *(x,y)* in px
         :type inflate: None, tuple, list
         :return: Widget rect
@@ -510,12 +532,11 @@ class Widget(object):
         # Padding + inflate
         if inflate is None:
             inflate = (0, 0)
-        apply_padding = 1
 
-        pad_top = self._padding[0] * apply_padding + inflate[1]
-        pad_right = self._padding[1] * apply_padding + inflate[0]
-        pad_bottom = self._padding[2] * apply_padding + inflate[1]
-        pad_left = self._padding[3] * apply_padding + inflate[0]
+        pad_top = self._padding[0] * apply_padding + inflate[1] / 2
+        pad_right = self._padding[1] * apply_padding + inflate[0] / 2
+        pad_bottom = self._padding[2] * apply_padding + inflate[1] / 2
+        pad_left = self._padding[3] * apply_padding + inflate[0] / 2
 
         return pygame.Rect(int(self._rect.x - pad_left),
                            int(self._rect.y - pad_top),
@@ -573,7 +594,7 @@ class Widget(object):
         Render text. If the font is not defined returns a zero-width surface.
 
         :param text: Text to render
-        :type text: str
+        :type text: str, None
         :param color: Text color
         :type color: tuple
         :param use_background_color: Use default background color
@@ -582,24 +603,21 @@ class Widget(object):
         :rtype: :py:class:`pygame.Surface`
         """
         # assert isinstance(text, str)
-        assert isinstance(color, tuple)
-        assert isinstance(use_background_color, bool)
+        assert isinstance(color, tuple), 'invalid color'
+        assert isinstance(use_background_color, bool), 'use_background_color must be boolean'
         bgcolor = self._font_background_color
 
-        # Background color must be opaque, otherwise the results are quite bad
-        if isinstance(bgcolor, (tuple, list)) and len(bgcolor) == 4 and bgcolor[3] != 255:
-            bgcolor = None
-
         # Disable
         if not use_background_color:
             bgcolor = None
 
         if self._font is None:
             return make_surface(0, 0)
+
         surface = self._font.render(text, self._font_antialias, color, bgcolor)
         return surface
 
-    def _render_string(self, string, color, enable_fill=True):
+    def _render_string(self, string, color):
         """
         Render text and turn it into a surface.
 
@@ -607,22 +625,16 @@ class Widget(object):
         :type string: str
         :param color: Text color
         :type color: tuple
-        :param enable_fill: Enable font fill
-        :type enable_fill: bool
         :return: Text surface
         :rtype: :py:class:`pygame.Surface`
         """
         text = self._font_render_string(string, color)
 
         # Create surface
-        fill_color = self._background_color
-        if not isinstance(fill_color, tuple) or not enable_fill:
-            fill_color = None
         surface = make_surface(
             width=text.get_width(),
             height=text.get_height(),
-            alpha=True,
-            fill_color=fill_color
+            alpha=True
         )
 
         # Draw shadow first
@@ -694,17 +706,28 @@ class Widget(object):
         :param selected_color: Text color when widget is selected
         :type selected_color: tuple
         :param background_color: Font background color
-        :type background_color: tuple
+        :type background_color: tuple, None
         :param antialias: Determines if antialias is applied to font (uses more processing power)
         :type antialias: bool
         :return: None
         """
         assert isinstance(font, str)
-        assert isinstance(font_size, int)
-        assert isinstance(color, tuple)
-        assert isinstance(selected_color, tuple)
-        assert isinstance(background_color, (tuple, type(None)))
+        assert isinstance(font_size, (int, float))
         assert isinstance(antialias, bool)
+        assert_color(color)
+        assert_color(selected_color)
+
+        if background_color is not None:
+            assert_color(background_color)
+
+            # If background is a color and it's transparent raise a warning
+            # Font background color must be opaque, otherwise the results are quite bad
+            if len(background_color) == 4 and background_color[3] != 255:
+                background_color = None
+                msg = 'font background color must be opaque, alpha channel must be 255'
+                warnings.warn(msg)
+
+        font_size = int(font_size)
 
         self._font = _fonts.get_font(font, font_size)
         self._font_antialias = antialias
@@ -779,7 +802,7 @@ class Widget(object):
         Set the menu reference.
 
         :param menu: Menu object
-        :type menu: :py:class:`pygame_menu.Menu`
+        :type menu: :py:class:`pygame_menu.Menu`, None
         :return: None
         """
         self._menu = menu
@@ -819,6 +842,79 @@ class Widget(object):
         self._rect.y = posy + self._translate[1]
         self._position_set = True
 
+    def get_position(self):
+        """
+        Return the widget position tuple *(x, y)*.
+
+        :return: Widget position
+        :rtype: tuple
+        """
+        return self._rect.x, self._rect.y
+
+    def get_width(self, apply_padding=True, apply_selection=False):
+        """
+        Return the widget width.
+
+        .. warning::
+
+            If the widget is not rendered, this method will return ``0``.
+
+        :param apply_padding: Apply padding
+        :type apply_selection: bool
+        :param apply_selection: Apply selection
+        :type apply_padding: bool
+        :return: Widget width (px)
+        :rtype: float
+        """
+        assert isinstance(apply_padding, bool)
+        assert isinstance(apply_selection, bool)
+        rect = self.get_rect(apply_padding=apply_padding)
+        width = rect.width
+        if apply_selection:
+            width += self._selection_effect.get_width()
+        return float(width)
+
+    def get_height(self, apply_padding=True, apply_selection=False):
+        """
+        Return the widget height.
+
+        .. warning::
+
+            If the widget is not rendered, this method will return ``0``.
+
+        :param apply_padding: Apply padding
+        :type apply_selection: bool
+        :param apply_selection: Apply selection
+        :type apply_padding: bool
+        :return: Widget height (px)
+        :rtype: float
+        """
+        assert isinstance(apply_padding, bool)
+        assert isinstance(apply_selection, bool)
+        rect = self.get_rect(apply_padding=apply_padding)
+        height = rect.height
+        if apply_selection:
+            height += self._selection_effect.get_height()
+        return float(height)
+
+    def get_size(self, apply_padding=True, apply_selection=False):
+        """
+        Return the widget size.
+
+        .. warning::
+
+            If the widget is not rendered this method might return ``(0,0)``.
+
+        :param apply_padding: Apply padding
+        :type apply_selection: bool
+        :param apply_selection: Apply selection
+        :type apply_padding: bool
+        :return: Widget *(width, height)*
+        :rtype: tuple
+        """
+        return self.get_width(apply_padding=apply_padding, apply_selection=apply_selection), \
+               self.get_height(apply_padding=apply_padding, apply_selection=apply_selection)
+
     def flip(self, x, y):
         """
         This method can flip the widget either vertically, horizontally, or both.
@@ -990,7 +1086,7 @@ class Widget(object):
         """
         pass
 
-    def set_shadow(self, enabled=True, color=None, position=None, offset=None):
+    def set_shadow(self, enabled=True, color=None, position=None, offset=2):
         """
         Show text shadow.
 
@@ -1011,11 +1107,10 @@ class Widget(object):
         if position is not None:
             assert_position(position)
             self._shadow_position = position
-        if offset is not None:
-            assert isinstance(offset, (int, float))
-            if offset <= 0:
-                raise ValueError('shadow offset must be greater than zero')
-            self._shadow_offset = offset
+        assert isinstance(offset, (int, float))
+        if offset <= 0:
+            raise ValueError('shadow offset must be greater than zero')
+        self._shadow_offset = offset
 
         self._create_shadow_tuple()  # Create shadow tuple position
         self._last_render_hash = 0  # Force widget render
@@ -1098,8 +1193,8 @@ class Widget(object):
         Update internal variable according to the given events list
         and fire the callbacks.
 
-        :param events: List of pygame events
-        :type events: list[:py:class:`pygame.event.Event`]
+        :param events: List/Tuple of pygame events
+        :type events: list[:py:class:`pygame.event.Event`], tuple[:py:class:`pygame.event.Event`]
         :return: True if updated
         :rtype: bool
         """
